@@ -49,9 +49,13 @@ class Subject(EntityType):
 
 class SurvivalData(EntityType):
     """ Survival data for patients"""
+    lastnews_date = Date()
+    state_at_lastnews = String(maxsize=2048)
     deceased = Boolean()
     relapse_date = Date()
-    survival_of = SubjectRelation('Subject', cardinality='1*', inlined=True, composite='object')
+    survival_of = SubjectRelation('Subject', cardinality='1*',
+                                  inlined=True, composite='object')
+    therapy_evaluation = SubjectRelation('TherapyEvaluation', cardinality='**')
 
 
 class Study(EntityType):
@@ -62,6 +66,9 @@ class Study(EntityType):
     keywords = String(maxsize=1024)
     themes = SubjectRelation('Theme', cardinality='**')
     substudy_of = SubjectRelation('Study', cardinality='?*', inlined=True)
+    principal_investigators = SubjectRelation('Investigator', cardinality='**')
+    start_date = Date()
+    end_date = Date()
 
 
 class Theme(EntityType):
@@ -86,6 +93,7 @@ class Admission(EntityType):
     subject_admission_number = String(fulltextindexed=True)
     admission_of = SubjectRelation('Subject', cardinality='1*', composite='object', inlined=True)
     admission_in = SubjectRelation('Study', cardinality='1*', inlined=True)
+    admission_scores = SubjectRelation('ScoreValue', cardinality='**')
     description = RichString(fulltextindexed=True, description=_('Additional admission infos'))
 
 
@@ -217,6 +225,22 @@ class Therapy(EntityType):
     related_study = SubjectRelation('Study', cardinality='?*', inlined=True)
     description = RichString(fulltextindexed=True)
 
+
+class TherapyEvaluation(EntityType):
+    """ Evaluation of a Therapy"""
+    therapy_start = Date()
+    therapy_stop = Date()
+    global_response = String(maxsize=2048)
+    progression_date = Date()
+    best_response = String(maxsize=2048)
+    best_response_date = Date()
+    survival_months = Int()
+    progression = String(maxsize=2048)
+    evaluation_of = SubjectRelation('Therapy', cardinality='1*', inlined=True)
+    evaluation_for = SubjectRelation('Subject', cardinality='1*',
+                                     composite='object', inlined=True)
+
+
 class DrugTake(EntityType):
     """ Drug take """
     start_taking_date = Date(required=True)
@@ -372,7 +396,6 @@ class performed_on(RelationDefinition):
     subject = 'TechnicalAnalysis'
     object = 'GenericMeasure'
     cardinality = '**'
-    composite = 'object'
 
 class concerns(RelationDefinition):
     subject = 'GenericMeasure'
