@@ -36,17 +36,19 @@ class MedicalexpContainersTC(CubicWebTC):
         cfg = SUBJECT_CONTAINER
         self.assertEqual((frozenset(['related_diagnostics', 'related_therapies',
                                      'taken_in_therapy', 'admission_of',
+                                     'evaluation_for',
                                      'step_of', 'survival_of']),
                           frozenset(['Diagnostic', 'Therapy', 'DrugTake',
+                                     'TherapyEvaluation',
                                      'Admission', 'AdmissionStep', 'SurvivalData'])),
                          cfg.structure(self.vreg.schema))
 
     def test_static_structure_assessment(self):
         cfg = ASSESSMENT_CONTAINER
         self.assertEqual(
-            (frozenset(['results_files', 'configuration_files', 'uses', 'performed_on',
+            (frozenset(['results_files', 'configuration_files', 'uses',
                         'generates', 'measure', 'file_entries']),
-             frozenset(['GenericMeasure', 'TechnicalAnalysis', 'ExternalFile',
+             frozenset(['GenericMeasure', 'ExternalFile',
                         'FileSet', 'ScoreValue', 'File'])),
             cfg.structure(self.vreg.schema))
 
